# diagrid subscription update

Update a pub/sub topic subscription

### Description

Update topic subscription for a pub/sub component in a project

```
diagrid subscription update <subscription> [flags]
```

### Examples

```

  # Update the default route where messages sent to the topic subscription are delivered
  diagrid subscription update my-subscription --route /method
  
  # Update the target pub/sub topic to which scoped applications will subscribe
  diagrid subscription update my-subscription --topic my-topic
  
  # Update the list of subscribing applications for the topic subscription
  diagrid subscription update my-subscription --scopes my-id-1,my-id-2

```

### Options

```
  -t, --topic string                       Name of the target pub/sub topic
  -r, --route string                       Route in the app code where messages will be delivered
  -s, --scopes strings                     List of subscribing ids. ids must exist in project and have access to the pub/sub component
  -c, --component string                   Name of the target pub/sub component
  -b, --bulk                               Enable bulk subscription
  -m, --bulk-max-messages-count int        Maximum number of messages to be sent in a single bulk subscription
  -a, --bulk-max-await-duration duration   Maximum duration to wait for messages to be sent in a single bulk subscription
  -p, --project string                     Name of existing project
  -w, --wait                               Wait for long-running resource update to finish
  -h, --help                               help for update
```

### Options inherited from parent commands

```
      --api-key string   Diagrid Cloud API key
```

### SEE ALSO

- [diagrid subscription](./subscription.md)	 - Manage pub/sub topic subscriptions
